==> simpleadb-0.3.0.tar.gz: simpleadb-0.3.0/simpleadb/adbprocess.py <==
""" Interface for adb process"""
import subprocess
from . import adbcmds  # pylint: disable=relative-beyond-top-level


class AdbProcess(object):  # pylint: disable=useless-object-inheritance
    """AdbProcess this class is used to call adb process

      Args:
        path (Optional[str]): adb path, default: 'adb'
      Returns:
        0 if success, otherwise error code
    """

    def __init__(self, path=adbcmds.ADB):
        self.__adb_path = path

    def call(self, args, **kwargs):
        """ Call process

          Args:
            args (str): Arguments
            **kwargs: Arbitrary keyword arguments
          Keyword Args:
            timeout (int): Timeout in sec
          Returns:
            0 if success, otherwise error code
        """
        cmd = ' '.join([
            self.__adb_path,
            args,
        ])
        kwargs.setdefault('shell', True)
        return subprocess.call(cmd, **kwargs)

    def check_call(self, args, **kwargs):
        """ Call process

          Args:
            args (str): Arguments
            **kwargs: Arbitrary keyword arguments
          Keyword Args:
            timeout (int): Timeout in sec
          Returns:
            0 if success
          Raises:
            CalledProcessError: when failed
        """
        cmd = ' '.join([
            self.__adb_path,
            args,
        ])
        kwargs.setdefault('shell', True)
        return subprocess.check_call(cmd, **kwargs)

    def check_output(self, args, **kwargs):
        """ Call process

          Args:
            args (str): Arguments
            **kwargs: Arbitrary keyword arguments
          Keyword Args:
            timeout (int): Timeout in sec
          Returns:
            0 if success
          Raises:
            CalledProcessError: when failed
        """
        cmd = ' '.join([
            self.__adb_path,
            args,
        ])
        kwargs.setdefault('shell', True)
        return subprocess.check_output(cmd, **kwargs)

==> simpleadb-0.3.4.tar.gz: simpleadb-0.3.4/simpleadb/adbprocess.py <==
#
# file adbprocess.py
#
# SPDX-FileCopyrightText: (c) 2019 Michal Kielan
#
# SPDX-License-Identifier: GPL-3.0-only
#

""" Interface for adb process"""
import subprocess
from typing import Optional
from . import adbcmds


class AdbProcess:
    """AdbProcess this class is used to call adb process

      Args:
        path (Optional[str]): adb path, default: 'adb'
      Returns:
        0 if success, otherwise error code
    """

    def __init__(self, path: Optional[str] = adbcmds.ADB):
        self.__adb_path = path

    def call(self, args, **kwargs):
        """ Call process

          Args:
            args (str): Arguments
            **kwargs: Arbitrary keyword arguments
          Keyword Args:
            timeout (int): Timeout in sec
          Returns:
            0 if success, otherwise error code
        """
        cmd = ' '.join([
            self.__adb_path,
            args,
        ])
        kwargs.setdefault('shell', True)
        return subprocess.call(cmd, **kwargs)

    def check_call(self, args: str, **kwargs) -> int:
        """ Call process

          Args:
            args (str): Arguments
            **kwargs: Arbitrary keyword arguments
          Keyword Args:
            timeout (int): Timeout in sec
          Returns:
            0 if success
          Raises:
            CalledProcessError: when failed
        """
        cmd = ' '.join([
            self.__adb_path,
            args,
        ])
        kwargs.setdefault('shell', True)
        return subprocess.check_call(cmd, **kwargs)

    def check_output(self, args: str, **kwargs) -> str:
        """ Call process

          Args:
            args (str): Arguments
            **kwargs: Arbitrary keyword arguments
          Keyword Args:
            timeout (int): Timeout in sec
          Returns:
            0 if success
          Raises:
            CalledProcessError: when failed
        """
        cmd = ' '.join([
            self.__adb_path,
            args,
        ])
        kwargs.setdefault('shell', True)
        kwargs.setdefault('universal_newlines', True)
        kwargs.setdefault('stderr', subprocess.STDOUT)
        return subprocess.check_output(cmd, **kwargs)
